@@ -1,6 +1,6 @@
 from .tensor import BackendRetriever as tensor
 from .optimize import OptimizerRetriever as optimize
-from .version import __version__
+from ._version import version as __version__
 from .exceptions import InvalidBackend, InvalidOptimizer, Unsupported
 from . import events
 
@@ -45,12 +45,12 @@ def set_backend(backend, custom_optimizer=None, precision=None):
         >>> pyhf.tensorlib.name
         'tensorflow'
         >>> pyhf.tensorlib.precision
-        '32b'
-        >>> pyhf.set_backend(b"pytorch", precision="64b")
+        '64b'
+        >>> pyhf.set_backend(b"pytorch", precision="32b")
         >>> pyhf.tensorlib.name
         'pytorch'
         >>> pyhf.tensorlib.precision
-        '64b'
+        '32b'
         >>> pyhf.set_backend(pyhf.tensor.numpy_backend())
         >>> pyhf.tensorlib.name
         'numpy'
@@ -155,15 +155,33 @@ from .pdf import Model
 from .workspace import Workspace
 from . import simplemodels
 from . import infer
+from . import compat
 from .patchset import PatchSet
 
 __all__ = [
-    'Model',
-    'Workspace',
-    'PatchSet',
-    'infer',
-    'utils',
-    'modifiers',
-    'simplemodels',
-    '__version__',
+    "Model",
+    "PatchSet",
+    "Workspace",
+    "__version__",
+    "compat",
+    "exceptions",
+    "get_backend",
+    "infer",
+    "interpolators",
+    "modifiers",
+    "optimizer",
+    "parameters",
+    "patchset",
+    "pdf",
+    "probability",
+    "set_backend",
+    "simplemodels",
+    "tensor",
+    "tensorlib",
+    "utils",
+    "workspace",
 ]
+
+
+def __dir__():
+    return __all__
