@@ -6,9 +6,15 @@ from io import BytesIO
 import logging
 from .. import exceptions
 
-logging.basicConfig()
 log = logging.getLogger(__name__)
 
+__all__ = ["download"]
+
+
+def __dir__():
+    return __all__
+
+
 try:
     import requests
 
