@@ -16,6 +16,18 @@ import logging
 
 log = logging.getLogger(__name__)
 
+__all__ = [
+    "AsymptoticCalculator",
+    "AsymptoticTestStatDistribution",
+    "EmpiricalDistribution",
+    "ToyCalculator",
+    "generate_asimov_data",
+]
+
+
+def __dir__():
+    return __all__
+
 
 def generate_asimov_data(asimov_mu, data, pdf, init_pars, par_bounds, fixed_params):
     """
@@ -25,8 +37,8 @@ def generate_asimov_data(asimov_mu, data, pdf, init_pars, par_bounds, fixed_para
 
         >>> import pyhf
         >>> pyhf.set_backend("numpy")
-        >>> model = pyhf.simplemodels.hepdata_like(
-        ...     signal_data=[12.0, 11.0], bkg_data=[50.0, 52.0], bkg_uncerts=[3.0, 7.0]
+        >>> model = pyhf.simplemodels.uncorrelated_background(
+        ...     signal=[12.0, 11.0], bkg=[50.0, 52.0], bkg_uncertainty=[3.0, 7.0]
         ... )
         >>> observations = [51, 48]
         >>> data = observations + model.config.auxdata
@@ -38,9 +50,12 @@ def generate_asimov_data(asimov_mu, data, pdf, init_pars, par_bounds, fixed_para
         asimov_mu (:obj:`float`): The value for the parameter of interest to be used.
         data (:obj:`tensor`): The observed data.
         pdf (~pyhf.pdf.Model): The statistical model adhering to the schema ``model.json``.
-        init_pars (:obj:`tensor`): The initial parameter values to be used for fitting.
-        par_bounds (:obj:`tensor`): The parameter value bounds to be used for fitting.
-        fixed_params (:obj:`tensor`): Parameters to be held constant in the fit.
+        init_pars (:obj:`tensor` of :obj:`float`): The starting values of the model parameters for minimization.
+        par_bounds (:obj:`tensor`): The extrema of values the model parameters
+            are allowed to reach in the fit.
+            The shape should be ``(n, 2)`` for ``n`` model parameters.
+        fixed_params (:obj:`tensor` of :obj:`bool`): The flag to set a parameter constant to its starting
+            value during minimization.
 
     Returns:
         Tensor: The Asimov dataset.
@@ -192,10 +207,12 @@ class AsymptoticCalculator:
         Args:
             data (:obj:`tensor`): The observed data.
             pdf (~pyhf.pdf.Model): The statistical model adhering to the schema ``model.json``.
-            init_pars (:obj:`tensor`): The initial parameter values to be used for fitting.
-            par_bounds (:obj:`tensor`): The parameter value bounds to be used for fitting.
-            fixed_params (:obj:`tensor`): Whether to fix the parameter to the init_pars value
-              during minimization.
+            init_pars (:obj:`tensor` of :obj:`float`): The starting values of the model parameters for minimization.
+            par_bounds (:obj:`tensor`): The extrema of values the model parameters
+                are allowed to reach in the fit.
+                The shape should be ``(n, 2)`` for ``n`` model parameters.
+            fixed_params (:obj:`tensor` of :obj:`bool`): The flag to set a parameter constant to its starting
+                value during minimization.
             test_stat (:obj:`str`): The test statistic to use as a numerical summary of the
               data: ``'qtilde'``, ``'q'``, or ``'q0'``.
 
@@ -245,8 +262,8 @@ class AsymptoticCalculator:
 
             >>> import pyhf
             >>> pyhf.set_backend("numpy")
-            >>> model = pyhf.simplemodels.hepdata_like(
-            ...     signal_data=[12.0, 11.0], bkg_data=[50.0, 52.0], bkg_uncerts=[3.0, 7.0]
+            >>> model = pyhf.simplemodels.uncorrelated_background(
+            ...     signal=[12.0, 11.0], bkg=[50.0, 52.0], bkg_uncertainty=[3.0, 7.0]
             ... )
             >>> observations = [51, 48]
             >>> data = observations + model.config.auxdata
@@ -287,8 +304,8 @@ class AsymptoticCalculator:
 
             >>> import pyhf
             >>> pyhf.set_backend("numpy")
-            >>> model = pyhf.simplemodels.hepdata_like(
-            ...     signal_data=[12.0, 11.0], bkg_data=[50.0, 52.0], bkg_uncerts=[3.0, 7.0]
+            >>> model = pyhf.simplemodels.uncorrelated_background(
+            ...     signal=[12.0, 11.0], bkg=[50.0, 52.0], bkg_uncertainty=[3.0, 7.0]
             ... )
             >>> observations = [51, 48]
             >>> data = observations + model.config.auxdata
@@ -366,8 +383,8 @@ class AsymptoticCalculator:
 
             >>> import pyhf
             >>> pyhf.set_backend("numpy")
-            >>> model = pyhf.simplemodels.hepdata_like(
-            ...     signal_data=[12.0, 11.0], bkg_data=[50.0, 52.0], bkg_uncerts=[3.0, 7.0]
+            >>> model = pyhf.simplemodels.uncorrelated_background(
+            ...     signal=[12.0, 11.0], bkg=[50.0, 52.0], bkg_uncertainty=[3.0, 7.0]
             ... )
             >>> observations = [51, 48]
             >>> data = observations + model.config.auxdata
@@ -411,8 +428,8 @@ class AsymptoticCalculator:
 
             >>> import pyhf
             >>> pyhf.set_backend("numpy")
-            >>> model = pyhf.simplemodels.hepdata_like(
-            ...     signal_data=[12.0, 11.0], bkg_data=[50.0, 52.0], bkg_uncerts=[3.0, 7.0]
+            >>> model = pyhf.simplemodels.uncorrelated_background(
+            ...     signal=[12.0, 11.0], bkg=[50.0, 52.0], bkg_uncertainty=[3.0, 7.0]
             ... )
             >>> observations = [51, 48]
             >>> data = observations + model.config.auxdata
@@ -443,7 +460,7 @@ class AsymptoticCalculator:
             map(
                 list,
                 zip(
-                    *[
+                    *(
                         self.pvalues(
                             test_stat, sig_plus_bkg_distribution, bkg_only_distribution
                         )
@@ -451,7 +468,7 @@ class AsymptoticCalculator:
                             bkg_only_distribution.expected_value(n_sigma)
                             for n_sigma in [2, 1, 0, -1, -2]
                         ]
-                    ]
+                    )
                 ),
             )
         )
@@ -502,8 +519,8 @@ class EmpiricalDistribution:
             >>> import numpy.random as random
             >>> random.seed(0)
             >>> pyhf.set_backend("numpy")
-            >>> model = pyhf.simplemodels.hepdata_like(
-            ...     signal_data=[12.0, 11.0], bkg_data=[50.0, 52.0], bkg_uncerts=[3.0, 7.0]
+            >>> model = pyhf.simplemodels.uncorrelated_background(
+            ...     signal=[12.0, 11.0], bkg=[50.0, 52.0], bkg_uncertainty=[3.0, 7.0]
             ... )
             >>> init_pars = model.config.suggested_init()
             >>> par_bounds = model.config.suggested_bounds()
@@ -558,8 +575,8 @@ class EmpiricalDistribution:
             >>> import numpy.random as random
             >>> random.seed(0)
             >>> pyhf.set_backend("numpy")
-            >>> model = pyhf.simplemodels.hepdata_like(
-            ...     signal_data=[12.0, 11.0], bkg_data=[50.0, 52.0], bkg_uncerts=[3.0, 7.0]
+            >>> model = pyhf.simplemodels.uncorrelated_background(
+            ...     signal=[12.0, 11.0], bkg=[50.0, 52.0], bkg_uncertainty=[3.0, 7.0]
             ... )
             >>> init_pars = model.config.suggested_init()
             >>> par_bounds = model.config.suggested_bounds()
@@ -618,10 +635,12 @@ class ToyCalculator:
         Args:
             data (:obj:`tensor`): The observed data.
             pdf (~pyhf.pdf.Model): The statistical model adhering to the schema ``model.json``.
-            init_pars (:obj:`tensor`): The initial parameter values to be used for fitting.
-            par_bounds (:obj:`tensor`): The parameter value bounds to be used for fitting.
-            fixed_params (:obj:`tensor`): Whether to fix the parameter to the init_pars value
-              during minimization.
+            init_pars (:obj:`tensor` of :obj:`float`): The starting values of the model parameters for minimization.
+            par_bounds (:obj:`tensor`): The extrema of values the model parameters
+                are allowed to reach in the fit.
+                The shape should be ``(n, 2)`` for ``n`` model parameters.
+            fixed_params (:obj:`tensor` of :obj:`bool`): The flag to set a parameter constant to its starting
+                value during minimization.
             test_stat (:obj:`str`): The test statistic to use as a numerical summary of the
               data: ``'qtilde'``, ``'q'``, or ``'q0'``.
               ``'qtilde'`` (default) performs the calculation using the alternative test statistic,
@@ -656,8 +675,8 @@ class ToyCalculator:
             >>> import numpy.random as random
             >>> random.seed(0)
             >>> pyhf.set_backend("numpy")
-            >>> model = pyhf.simplemodels.hepdata_like(
-            ...     signal_data=[12.0, 11.0], bkg_data=[50.0, 52.0], bkg_uncerts=[3.0, 7.0]
+            >>> model = pyhf.simplemodels.uncorrelated_background(
+            ...     signal=[12.0, 11.0], bkg=[50.0, 52.0], bkg_uncertainty=[3.0, 7.0]
             ... )
             >>> observations = [51, 48]
             >>> data = observations + model.config.auxdata
@@ -742,8 +761,8 @@ class ToyCalculator:
             >>> import numpy.random as random
             >>> random.seed(0)
             >>> pyhf.set_backend("numpy")
-            >>> model = pyhf.simplemodels.hepdata_like(
-            ...     signal_data=[12.0, 11.0], bkg_data=[50.0, 52.0], bkg_uncerts=[3.0, 7.0]
+            >>> model = pyhf.simplemodels.uncorrelated_background(
+            ...     signal=[12.0, 11.0], bkg=[50.0, 52.0], bkg_uncertainty=[3.0, 7.0]
             ... )
             >>> observations = [51, 48]
             >>> data = observations + model.config.auxdata
@@ -789,8 +808,8 @@ class ToyCalculator:
             >>> import numpy.random as random
             >>> random.seed(0)
             >>> pyhf.set_backend("numpy")
-            >>> model = pyhf.simplemodels.hepdata_like(
-            ...     signal_data=[12.0, 11.0], bkg_data=[50.0, 52.0], bkg_uncerts=[3.0, 7.0]
+            >>> model = pyhf.simplemodels.uncorrelated_background(
+            ...     signal=[12.0, 11.0], bkg=[50.0, 52.0], bkg_uncertainty=[3.0, 7.0]
             ... )
             >>> observations = [51, 48]
             >>> data = observations + model.config.auxdata
@@ -846,8 +865,8 @@ class ToyCalculator:
             >>> import numpy.random as random
             >>> random.seed(0)
             >>> pyhf.set_backend("numpy")
-            >>> model = pyhf.simplemodels.hepdata_like(
-            ...     signal_data=[12.0, 11.0], bkg_data=[50.0, 52.0], bkg_uncerts=[3.0, 7.0]
+            >>> model = pyhf.simplemodels.uncorrelated_background(
+            ...     signal=[12.0, 11.0], bkg=[50.0, 52.0], bkg_uncertainty=[3.0, 7.0]
             ... )
             >>> observations = [51, 48]
             >>> data = observations + model.config.auxdata
