@@ -16,6 +16,12 @@ from .mixins import _ChannelSummaryMixin
 
 log = logging.getLogger(__name__)
 
+__all__ = ["Model", "_ModelConfig"]
+
+
+def __dir__():
+    return __all__
+
 
 def _paramset_requirements_from_channelspec(spec, channel_nbins):
     # bookkeep all requirements for paramsets we need to build
@@ -151,7 +157,7 @@ def _nominal_and_modifiers_from_spec(config, spec):
                 if mtype == 'histosys':
                     lo_data = thismod['data']['lo_data'] if thismod else nom
                     hi_data = thismod['data']['hi_data'] if thismod else nom
-                    maskval = True if thismod else False
+                    maskval = bool(thismod)
                     mega_mods[key][s]['data']['lo_data'] += lo_data
                     mega_mods[key][s]['data']['hi_data'] += hi_data
                     mega_mods[key][s]['data']['nom_data'] += nom
@@ -159,7 +165,7 @@ def _nominal_and_modifiers_from_spec(config, spec):
                         nom
                     )  # broadcasting
                 elif mtype == 'normsys':
-                    maskval = True if thismod else False
+                    maskval = bool(thismod)
                     lo_factor = thismod['data']['lo'] if thismod else 1.0
                     hi_factor = thismod['data']['hi'] if thismod else 1.0
                     mega_mods[key][s]['data']['nom_data'] += [1.0] * len(nom)
@@ -171,7 +177,7 @@ def _nominal_and_modifiers_from_spec(config, spec):
                         nom
                     )  # broadcasting
                 elif mtype in ['normfactor', 'shapefactor', 'lumi']:
-                    maskval = True if thismod else False
+                    maskval = bool(thismod)
                     mega_mods[key][s]['data']['mask'] += [maskval] * len(
                         nom
                     )  # broadcasting
@@ -180,7 +186,7 @@ def _nominal_and_modifiers_from_spec(config, spec):
                     if mtype == 'shapesys':
                         maskval = [(x > 0 and y > 0) for x, y in zip(uncrt, nom)]
                     else:
-                        maskval = [True if thismod else False] * len(nom)
+                        maskval = [bool(thismod)] * len(nom)
                     mega_mods[key][s]['data']['mask'] += maskval
                     mega_mods[key][s]['data']['uncrt'] += uncrt
                     mega_mods[key][s]['data']['nom_data'] += nom
@@ -205,7 +211,22 @@ def _nominal_and_modifiers_from_spec(config, spec):
 
 
 class _ModelConfig(_ChannelSummaryMixin):
+    """
+    Configuration for the :class:`~pyhf.pdf.Model`.
+
+    .. note::
+
+        :class:`_ModelConfig` should not be called directly.
+        It should instead by accessed through the :obj:`config` attribute
+        of :class:`~pyhf.pdf.Model`.
+
+    """
+
     def __init__(self, spec, **config_kwargs):
+        """
+        Args:
+            spec (:obj:`jsonable`): The HistFactory JSON specification.
+        """
         super().__init__(channels=spec['channels'])
         _required_paramsets = _paramset_requirements_from_modelspec(
             spec, self.channel_nbins
@@ -241,21 +262,79 @@ class _ModelConfig(_ChannelSummaryMixin):
         self.nmaindata = sum(self.channel_nbins.values())
 
     def suggested_init(self):
+        """
+        Return suggested initial parameter values for the model.
+
+        Returns:
+            :obj:`list`: Suggested initial model parameters.
+
+        Example:
+            >>> import pyhf
+            >>> model = pyhf.simplemodels.uncorrelated_background(
+            ...     signal=[12.0, 11.0], bkg=[50.0, 52.0], bkg_uncertainty=[3.0, 7.0]
+            ... )
+            >>> model.config.suggested_init()
+            [1.0, 1.0, 1.0]
+        """
         init = []
         for name in self.par_order:
             init = init + self.par_map[name]['paramset'].suggested_init
         return init
 
     def suggested_bounds(self):
+        """
+        Return suggested parameter bounds for the model.
+
+        Returns:
+            :obj:`list`: Suggested bounds on model parameters.
+
+        Example:
+            >>> import pyhf
+            >>> model = pyhf.simplemodels.uncorrelated_background(
+            ...     signal=[12.0, 11.0], bkg=[50.0, 52.0], bkg_uncertainty=[3.0, 7.0]
+            ... )
+            >>> model.config.suggested_bounds()
+            [(0, 10), (1e-10, 10.0), (1e-10, 10.0)]
+        """
         bounds = []
         for name in self.par_order:
             bounds = bounds + self.par_map[name]['paramset'].suggested_bounds
         return bounds
 
     def par_slice(self, name):
+        """
+        The slice of the model parameter tensor corresponding to the model
+        parameter ``name``.
+
+        Returns:
+            :obj:`slice`: Slice of the model parameter tensor.
+
+        Example:
+            >>> import pyhf
+            >>> model = pyhf.simplemodels.uncorrelated_background(
+            ...     signal=[12.0, 11.0], bkg=[50.0, 52.0], bkg_uncertainty=[3.0, 7.0]
+            ... )
+            >>> model.config.par_slice("uncorr_bkguncrt")
+            slice(1, 3, None)
+        """
         return self.par_map[name]['slice']
 
     def param_set(self, name):
+        """
+        The :class:`~pyhf.parameters.paramset` for the model parameter ``name``.
+
+        Returns:
+            :obj:`~pyhf.parameters.paramsets`: Corresponding :obj:`paramset`.
+
+        Example:
+            >>> import pyhf
+            >>> model = pyhf.simplemodels.uncorrelated_background(
+            ...     signal=[12.0, 11.0], bkg=[50.0, 52.0], bkg_uncertainty=[3.0, 7.0]
+            ... )
+            >>> param_set = model.config.param_set("uncorr_bkguncrt")
+            >>> param_set.pdf_type
+            'poisson'
+        """
         return self.par_map[name]['paramset']
 
     def suggested_fixed(self):
@@ -263,14 +342,23 @@ class _ModelConfig(_ChannelSummaryMixin):
         Identify the fixed parameters in the model.
 
         Returns:
-            List: A list of booleans, ``True`` for fixed and ``False`` for not fixed.
+            :obj:`list`: A list of booleans, ``True`` for fixed and ``False``
+            for not fixed.
 
-        Something like the following to build fixed_vals appropriately:
+        Example:
+            >>> import pyhf
+            >>> model = pyhf.simplemodels.uncorrelated_background(
+            ...     signal=[12.0, 11.0], bkg=[50.0, 52.0], bkg_uncertainty=[3.0, 7.0]
+            ... )
+            >>> model.config.suggested_fixed()
+            [False, False, False]
+
+        Something like the following to build ``fixed_vals`` appropriately:
 
         .. code:: python
 
-            fixed_pars = pdf.config.suggested_fixed()
-            inits = pdf.config.suggested_init()
+            fixed_pars = model.config.suggested_fixed()
+            inits = model.config.suggested_init()
             fixed_vals = [
                 (index, init)
                 for index, (init, is_fixed) in enumerate(zip(inits, fixed_pars))
@@ -284,6 +372,18 @@ class _ModelConfig(_ChannelSummaryMixin):
         return fixed
 
     def set_poi(self, name):
+        """
+        Set the model parameter of interest to be model parameter ``name``.
+
+        Example:
+            >>> import pyhf
+            >>> model = pyhf.simplemodels.uncorrelated_background(
+            ...     signal=[12.0, 11.0], bkg=[50.0, 52.0], bkg_uncertainty=[3.0, 7.0]
+            ... )
+            >>> model.config.set_poi("mu")
+            >>> model.config.poi_name
+            'mu'
+        """
         if name not in [x for x, _ in self.modifiers]:
             raise exceptions.InvalidModel(
                 f"The parameter of interest '{name:s}' cannot be fit as it is not declared in the model specification."
