@@ -16,6 +16,12 @@ from .mixins import _ChannelSummaryMixin
 
 log = logging.getLogger(__name__)
 
+__all__ = ["Workspace"]
+
+
+def __dir__():
+    return __all__
+
 
 def _join_items(join, left_items, right_items, key='name', deep_merge_key=None):
     """
@@ -260,10 +266,10 @@ def _join_measurements(join, left_measurements, right_measurements):
                         'poi': measurements[0]['config']['poi'],
                         'parameters': _join_parameter_configs(
                             measurement_name,
-                            *[
+                            *(
                                 measurement['config']['parameters']
                                 for measurement in measurements
-                            ],
+                            ),
                         ),
                     },
                 }
